@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Parser;
-$Test::BDD::Cucumber::Parser::VERSION = '0.70';
+$Test::BDD::Cucumber::Parser::VERSION = '0.71';
 =head1 NAME
 
 Test::BDD::Cucumber::Parser - Parse Feature files
 
 =head1 VERSION
 
-version 0.70
+version 0.71
 
 =head1 DESCRIPTION
 
@@ -164,7 +164,9 @@ sub _extract_language {
     my ( $self, $lines ) = @_;
 
 # return default language if we don't see the language directive on the first line
-    return 'en' unless $lines->[0]->raw_content =~ m{^\s*#\s*language:\s+(.+)$};
+    return 'en'
+        unless ($lines and @$lines
+                and $lines->[0]->raw_content =~ m{^\s*#\s*language:\s+(.+)$});
 
     # remove the language directive if we saw it ...
     shift @$lines;
